==> ros-bloom_0.6.1.orig.tar.gz: bloom-0.6.1/bloom/commands/generate.py <==
# Software License Agreement (BSD License)
#
# Copyright (c) 2013, Open Source Robotics Foundation, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following
#    disclaimer in the documentation and/or other materials provided
#    with the distribution.
#  * Neither the name of Open Source Robotics Foundation, Inc. nor
#    the names of its contributors may be used to endorse or promote
#    products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from __future__ import print_function

import argparse
import sys
import pkg_resources

from bloom.util import add_global_arguments
from bloom.util import handle_global_arguments

BLOOM_GENERATE_CMDS_GROUP = 'bloom.generate_cmds'


def list_generator_commands():
    generators = []
    for entry_point in pkg_resources.iter_entry_points(group=BLOOM_GENERATE_CMDS_GROUP):
        generators.append(entry_point.name)
    return generators


def load_generator_description(generator_name):
    for entry_point in pkg_resources.iter_entry_points(group=BLOOM_GENERATE_CMDS_GROUP):
        if entry_point.name == generator_name:
            return entry_point.load()


def create_subparsers(parser, generator_cmds):
    metavar = '[' + ' | '.join(generator_cmds) + ']'
    subparser = parser.add_subparsers(
        title='generate commands',
        metavar=metavar,
        description='Call `bloom-generate {0} -h` for help on a each generate command.'.format(metavar),
        dest='generator_cmd'
    )
    for generator_cmd in generator_cmds:
        desc = load_generator_description(generator_cmd)
        cmd_parser = subparser.add_parser(desc['title'], description=desc['description'])
        cmd_parser = desc['prepare_arguments'](cmd_parser)
        cmd_parser.set_defaults(func=desc['main'])
        add_global_arguments(cmd_parser)


def main(sysargs=None):
    parser = argparse.ArgumentParser(
        description="Calls a generator on a local package, e.g. bloom-generate debian"
    )

    generator_cmds = list_generator_commands()

    create_subparsers(parser, generator_cmds)

    args = parser.parse_args(sysargs)
    handle_global_arguments(args)

    sys.exit(args.func(args) or 0)

==> ros-bloom_0.13.0.orig.tar.gz: bloom-0.13.0/bloom/commands/generate.py <==
# Software License Agreement (BSD License)
#
# Copyright (c) 2013, Open Source Robotics Foundation, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above
#    copyright notice, this list of conditions and the following
#    disclaimer in the documentation and/or other materials provided
#    with the distribution.
#  * Neither the name of Open Source Robotics Foundation, Inc. nor
#    the names of its contributors may be used to endorse or promote
#    products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from __future__ import print_function

import argparse
import sys
import pkg_resources

from bloom.util import add_global_arguments
from bloom.util import handle_global_arguments

BLOOM_GENERATE_CMDS_GROUP = 'bloom.generate_cmds'


def list_generator_commands():
    generators = []
    for entry_point in pkg_resources.iter_entry_points(group=BLOOM_GENERATE_CMDS_GROUP):
        generators.append(entry_point.name)
    return generators


def load_generator_description(generator_name):
    for entry_point in pkg_resources.iter_entry_points(group=BLOOM_GENERATE_CMDS_GROUP):
        if entry_point.name == generator_name:
            return entry_point.load()


def create_subparsers(parser, generator_cmds):
    metavar = '[' + ' | '.join(generator_cmds) + ']'
    subparsers_kwargs = {
      'title': 'generate commands',
      'metavar': metavar,
      'description': 'Call `bloom-generate {0} -h` for help on a each generate command.'.format(metavar),
      'dest': 'generator_cmd'
    }
    if sys.version_info >= (3, 7):
        subparsers_kwargs['required'] = True
    subparsers = parser.add_subparsers(**subparsers_kwargs)
    for generator_cmd in generator_cmds:
        desc = load_generator_description(generator_cmd)
        cmd_parser = subparsers.add_parser(desc['title'], description=desc['description'])
        cmd_parser = desc['prepare_arguments'](cmd_parser)
        cmd_parser.set_defaults(func=desc['main'])
        add_global_arguments(cmd_parser)


def main(sysargs=None):
    parser = argparse.ArgumentParser(
        description="Calls a generator on a local package, e.g. bloom-generate debian"
    )

    generator_cmds = list_generator_commands()

    create_subparsers(parser, generator_cmds)

    args = parser.parse_args(sysargs)
    handle_global_arguments(args)

    sys.exit(args.func(args) or 0)
